<?php

/*
 * SPDX-License-Identifier: AGPL-3.0-only
 * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
 * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
 *
 * Indicates that a synchronization state could not be retrieved
 * from an IStateMachine.
 */
class StateNotFoundException extends StatusException {}
